==> webpdf-wsclient-2.0.3-sources.jar: net/webpdf/wsclient/schema/operation/Pdf417BarcodeType.java <==

package net.webpdf.wsclient.schema.operation;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for Pdf417BarcodeType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="Pdf417BarcodeType"&gt;
 *   &lt;complexContent&gt;
 *     &lt;extension base="{http://schema.webpdf.de/1.0/operation}BaseBarcodeType"&gt;
 *       &lt;attribute name="errorCorrection" default="2"&gt;
 *         &lt;simpleType&gt;
 *           &lt;restriction base="{http://www.w3.org/2001/XMLSchema}int"&gt;
 *             &lt;minInclusive value="1"/&gt;
 *             &lt;maxInclusive value="8"/&gt;
 *           &lt;/restriction&gt;
 *         &lt;/simpleType&gt;
 *       &lt;/attribute&gt;
 *       &lt;attribute name="compact" type="{http://www.w3.org/2001/XMLSchema}boolean" default="false" /&gt;
 *       &lt;attribute name="compactionMode" type="{http://schema.webpdf.de/1.0/operation}Pdf417CompactionModeType" default="auto" /&gt;
 *       &lt;attribute name="dataCodewordsMin"&gt;
 *         &lt;simpleType&gt;
 *           &lt;restriction base="{http://www.w3.org/2001/XMLSchema}int"&gt;
 *             &lt;minInclusive value="1"/&gt;
 *           &lt;/restriction&gt;
 *         &lt;/simpleType&gt;
 *       &lt;/attribute&gt;
 *       &lt;attribute name="dataCodewordsMax"&gt;
 *         &lt;simpleType&gt;
 *           &lt;restriction base="{http://www.w3.org/2001/XMLSchema}int"&gt;
 *             &lt;minInclusive value="1"/&gt;
 *           &lt;/restriction&gt;
 *         &lt;/simpleType&gt;
 *       &lt;/attribute&gt;
 *       &lt;attribute name="symbolsPerCodewordMin"&gt;
 *         &lt;simpleType&gt;
 *           &lt;restriction base="{http://www.w3.org/2001/XMLSchema}int"&gt;
 *             &lt;minInclusive value="1"/&gt;
 *           &lt;/restriction&gt;
 *         &lt;/simpleType&gt;
 *       &lt;/attribute&gt;
 *       &lt;attribute name="symbolsPerCodewordMax"&gt;
 *         &lt;simpleType&gt;
 *           &lt;restriction base="{http://www.w3.org/2001/XMLSchema}int"&gt;
 *             &lt;minInclusive value="1"/&gt;
 *           &lt;/restriction&gt;
 *         &lt;/simpleType&gt;
 *       &lt;/attribute&gt;
 *       &lt;attribute name="shape" type="{http://schema.webpdf.de/1.0/operation}DataMatrixShapeType" default="default" /&gt;
 *     &lt;/extension&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "Pdf417BarcodeType")
public class Pdf417BarcodeType
    extends BaseBarcodeType
{

    @XmlAttribute(name = "errorCorrection")
    protected Integer errorCorrection;
    @XmlAttribute(name = "compact")
    protected Boolean compact;
    @XmlAttribute(name = "compactionMode")
    protected Pdf417CompactionModeType compactionMode;
    @XmlAttribute(name = "dataCodewordsMin")
    protected Integer dataCodewordsMin;
    @XmlAttribute(name = "dataCodewordsMax")
    protected Integer dataCodewordsMax;
    @XmlAttribute(name = "symbolsPerCodewordMin")
    protected Integer symbolsPerCodewordMin;
    @XmlAttribute(name = "symbolsPerCodewordMax")
    protected Integer symbolsPerCodewordMax;
    @XmlAttribute(name = "shape")
    protected DataMatrixShapeType shape;

    /**
     * Gets the value of the errorCorrection property.
     * 
     * @return
     *     possible object is
     *     {@link Integer }
     *     
     */
    public int getErrorCorrection() {
        if (errorCorrection == null) {
            return  2;
        } else {
            return errorCorrection;
        }
    }

    /**
     * Sets the value of the errorCorrection property.
     * 
     * @param value
     *     allowed object is
     *     {@link Integer }
     *     
     */
    public void setErrorCorrection(int value) {
        this.errorCorrection = value;
    }

    public boolean isSetErrorCorrection() {
        return (this.errorCorrection!= null);
    }

    public void unsetErrorCorrection() {
        this.errorCorrection = null;
    }

    /**
     * Gets the value of the compact property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isCompact() {
        if (compact == null) {
            return false;
        } else {
            return compact;
        }
    }

    /**
     * Sets the value of the compact property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setCompact(boolean value) {
        this.compact = value;
    }

    public boolean isSetCompact() {
        return (this.compact!= null);
    }

    public void unsetCompact() {
        this.compact = null;
    }

    /**
     * Gets the value of the compactionMode property.
     * 
     * @return
     *     possible object is
     *     {@link Pdf417CompactionModeType }
     *     
     */
    public Pdf417CompactionModeType getCompactionMode() {
        if (compactionMode == null) {
            return Pdf417CompactionModeType.AUTO;
        } else {
            return compactionMode;
        }
    }

    /**
     * Sets the value of the compactionMode property.
     * 
     * @param value
     *     allowed object is
     *     {@link Pdf417CompactionModeType }
     *     
     */
    public void setCompactionMode(Pdf417CompactionModeType value) {
        this.compactionMode = value;
    }

    public boolean isSetCompactionMode() {
        return (this.compactionMode!= null);
    }

    /**
     * Gets the value of the dataCodewordsMin property.
     * 
     * @return
     *     possible object is
     *     {@link Integer }
     *     
     */
    public int getDataCodewordsMin() {
        return dataCodewordsMin;
    }

    /**
     * Sets the value of the dataCodewordsMin property.
     * 
     * @param value
     *     allowed object is
     *     {@link Integer }
     *     
     */
    public void setDataCodewordsMin(int value) {
        this.dataCodewordsMin = value;
    }

    public boolean isSetDataCodewordsMin() {
        return (this.dataCodewordsMin!= null);
    }

    public void unsetDataCodewordsMin() {
        this.dataCodewordsMin = null;
    }

    /**
     * Gets the value of the dataCodewordsMax property.
     * 
     * @return
     *     possible object is
     *     {@link Integer }
     *     
     */
    public int getDataCodewordsMax() {
        return dataCodewordsMax;
    }

    /**
     * Sets the value of the dataCodewordsMax property.
     * 
     * @param value
     *     allowed object is
     *     {@link Integer }
     *     
     */
    public void setDataCodewordsMax(int value) {
        this.dataCodewordsMax = value;
    }

    public boolean isSetDataCodewordsMax() {
        return (this.dataCodewordsMax!= null);
    }

    public void unsetDataCodewordsMax() {
        this.dataCodewordsMax = null;
    }

    /**
     * Gets the value of the symbolsPerCodewordMin property.
     * 
     * @return
     *     possible object is
     *     {@link Integer }
     *     
     */
    public int getSymbolsPerCodewordMin() {
        return symbolsPerCodewordMin;
    }

    /**
     * Sets the value of the symbolsPerCodewordMin property.
     * 
     * @param value
     *     allowed object is
     *     {@link Integer }
     *     
     */
    public void setSymbolsPerCodewordMin(int value) {
        this.symbolsPerCodewordMin = value;
    }

    public boolean isSetSymbolsPerCodewordMin() {
        return (this.symbolsPerCodewordMin!= null);
    }

    public void unsetSymbolsPerCodewordMin() {
        this.symbolsPerCodewordMin = null;
    }

    /**
     * Gets the value of the symbolsPerCodewordMax property.
     * 
     * @return
     *     possible object is
     *     {@link Integer }
     *     
     */
    public int getSymbolsPerCodewordMax() {
        return symbolsPerCodewordMax;
    }

    /**
     * Sets the value of the symbolsPerCodewordMax property.
     * 
     * @param value
     *     allowed object is
     *     {@link Integer }
     *     
     */
    public void setSymbolsPerCodewordMax(int value) {
        this.symbolsPerCodewordMax = value;
    }

    public boolean isSetSymbolsPerCodewordMax() {
        return (this.symbolsPerCodewordMax!= null);
    }

    public void unsetSymbolsPerCodewordMax() {
        this.symbolsPerCodewordMax = null;
    }

    /**
     * Gets the value of the shape property.
     * 
     * @return
     *     possible object is
     *     {@link DataMatrixShapeType }
     *     
     */
    public DataMatrixShapeType getShape() {
        if (shape == null) {
            return DataMatrixShapeType.DEFAULT;
        } else {
            return shape;
        }
    }

    /**
     * Sets the value of the shape property.
     * 
     * @param value
     *     allowed object is
     *     {@link DataMatrixShapeType }
     *     
     */
    public void setShape(DataMatrixShapeType value) {
        this.shape = value;
    }

    public boolean isSetShape() {
        return (this.shape!= null);
    }

}

==> webpdf-wsclient-9.0.0-sources.jar: net/webpdf/wsclient/schema/operation/Pdf417BarcodeType.java <==

package net.webpdf.wsclient.schema.operation;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlType;


/**
 * 
 * <pre>
 * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;p xmlns:p523158_="https://jakarta.ee/xml/ns/jaxb" xmlns:p795835_="http://jaxb2-commons.dev.java.net/basic/simplify" xmlns:p918168_="http://jaxb2-commons.dev.java.net/basic/inheritance" xmlns:tns="http://schema.webpdf.de/1.0/operation" xmlns:xs="http://www.w3.org/2001/XMLSchema"&gt;A PDF417 barcode.&lt;/p&gt;
 * </pre>
 * 
 * 
 * <p>Java class for Pdf417BarcodeType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType name="Pdf417BarcodeType">
 *   <complexContent>
 *     <extension base="{http://schema.webpdf.de/1.0/operation}BaseBarcodeType">
 *       <attribute name="errorCorrection" default="2">
 *         <simpleType>
 *           <restriction base="{http://www.w3.org/2001/XMLSchema}int">
 *             <minInclusive value="1"/>
 *             <maxInclusive value="8"/>
 *           </restriction>
 *         </simpleType>
 *       </attribute>
 *       <attribute name="compact" type="{http://www.w3.org/2001/XMLSchema}boolean" default="false" />
 *       <attribute name="compactionMode" type="{http://schema.webpdf.de/1.0/operation}Pdf417CompactionModeType" default="auto" />
 *       <attribute name="dataCodewordsMin">
 *         <simpleType>
 *           <restriction base="{http://www.w3.org/2001/XMLSchema}int">
 *             <minInclusive value="1"/>
 *           </restriction>
 *         </simpleType>
 *       </attribute>
 *       <attribute name="dataCodewordsMax">
 *         <simpleType>
 *           <restriction base="{http://www.w3.org/2001/XMLSchema}int">
 *             <minInclusive value="1"/>
 *           </restriction>
 *         </simpleType>
 *       </attribute>
 *       <attribute name="symbolsPerCodewordMin">
 *         <simpleType>
 *           <restriction base="{http://www.w3.org/2001/XMLSchema}int">
 *             <minInclusive value="1"/>
 *           </restriction>
 *         </simpleType>
 *       </attribute>
 *       <attribute name="symbolsPerCodewordMax">
 *         <simpleType>
 *           <restriction base="{http://www.w3.org/2001/XMLSchema}int">
 *             <minInclusive value="1"/>
 *           </restriction>
 *         </simpleType>
 *       </attribute>
 *       <attribute name="shape" type="{http://schema.webpdf.de/1.0/operation}DataMatrixShapeType" default="default" />
 *     </extension>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "Pdf417BarcodeType")
public class Pdf417BarcodeType
    extends BaseBarcodeType
{

    @XmlAttribute(name = "errorCorrection")
    protected Integer errorCorrection;
    @XmlAttribute(name = "compact")
    protected Boolean compact;
    @XmlAttribute(name = "compactionMode")
    protected Pdf417CompactionModeType compactionMode;
    @XmlAttribute(name = "dataCodewordsMin")
    protected Integer dataCodewordsMin;
    @XmlAttribute(name = "dataCodewordsMax")
    protected Integer dataCodewordsMax;
    @XmlAttribute(name = "symbolsPerCodewordMin")
    protected Integer symbolsPerCodewordMin;
    @XmlAttribute(name = "symbolsPerCodewordMax")
    protected Integer symbolsPerCodewordMax;
    @XmlAttribute(name = "shape")
    protected DataMatrixShapeType shape;

    /**
     * Gets the value of the errorCorrection property.
     * 
     * @return
     *     possible object is
     *     {@link Integer }
     *     
     */
    public int getErrorCorrection() {
        if (errorCorrection == null) {
            return  2;
        } else {
            return errorCorrection;
        }
    }

    /**
     * Sets the value of the errorCorrection property.
     * 
     * @param value
     *     allowed object is
     *     {@link Integer }
     *     
     */
    public void setErrorCorrection(int value) {
        this.errorCorrection = value;
    }

    public boolean isSetErrorCorrection() {
        return (this.errorCorrection!= null);
    }

    public void unsetErrorCorrection() {
        this.errorCorrection = null;
    }

    /**
     * Gets the value of the compact property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isCompact() {
        if (compact == null) {
            return false;
        } else {
            return compact;
        }
    }

    /**
     * Sets the value of the compact property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setCompact(boolean value) {
        this.compact = value;
    }

    public boolean isSetCompact() {
        return (this.compact!= null);
    }

    public void unsetCompact() {
        this.compact = null;
    }

    /**
     * Gets the value of the compactionMode property.
     * 
     * @return
     *     possible object is
     *     {@link Pdf417CompactionModeType }
     *     
     */
    public Pdf417CompactionModeType getCompactionMode() {
        if (compactionMode == null) {
            return Pdf417CompactionModeType.AUTO;
        } else {
            return compactionMode;
        }
    }

    /**
     * Sets the value of the compactionMode property.
     * 
     * @param value
     *     allowed object is
     *     {@link Pdf417CompactionModeType }
     *     
     */
    public void setCompactionMode(Pdf417CompactionModeType value) {
        this.compactionMode = value;
    }

    public boolean isSetCompactionMode() {
        return (this.compactionMode!= null);
    }

    /**
     * Gets the value of the dataCodewordsMin property.
     * 
     * @return
     *     possible object is
     *     {@link Integer }
     *     
     */
    public int getDataCodewordsMin() {
        return dataCodewordsMin;
    }

    /**
     * Sets the value of the dataCodewordsMin property.
     * 
     * @param value
     *     allowed object is
     *     {@link Integer }
     *     
     */
    public void setDataCodewordsMin(int value) {
        this.dataCodewordsMin = value;
    }

    public boolean isSetDataCodewordsMin() {
        return (this.dataCodewordsMin!= null);
    }

    public void unsetDataCodewordsMin() {
        this.dataCodewordsMin = null;
    }

    /**
     * Gets the value of the dataCodewordsMax property.
     * 
     * @return
     *     possible object is
     *     {@link Integer }
     *     
     */
    public int getDataCodewordsMax() {
        return dataCodewordsMax;
    }

    /**
     * Sets the value of the dataCodewordsMax property.
     * 
     * @param value
     *     allowed object is
     *     {@link Integer }
     *     
     */
    public void setDataCodewordsMax(int value) {
        this.dataCodewordsMax = value;
    }

    public boolean isSetDataCodewordsMax() {
        return (this.dataCodewordsMax!= null);
    }

    public void unsetDataCodewordsMax() {
        this.dataCodewordsMax = null;
    }

    /**
     * Gets the value of the symbolsPerCodewordMin property.
     * 
     * @return
     *     possible object is
     *     {@link Integer }
     *     
     */
    public int getSymbolsPerCodewordMin() {
        return symbolsPerCodewordMin;
    }

    /**
     * Sets the value of the symbolsPerCodewordMin property.
     * 
     * @param value
     *     allowed object is
     *     {@link Integer }
     *     
     */
    public void setSymbolsPerCodewordMin(int value) {
        this.symbolsPerCodewordMin = value;
    }

    public boolean isSetSymbolsPerCodewordMin() {
        return (this.symbolsPerCodewordMin!= null);
    }

    public void unsetSymbolsPerCodewordMin() {
        this.symbolsPerCodewordMin = null;
    }

    /**
     * Gets the value of the symbolsPerCodewordMax property.
     * 
     * @return
     *     possible object is
     *     {@link Integer }
     *     
     */
    public int getSymbolsPerCodewordMax() {
        return symbolsPerCodewordMax;
    }

    /**
     * Sets the value of the symbolsPerCodewordMax property.
     * 
     * @param value
     *     allowed object is
     *     {@link Integer }
     *     
     */
    public void setSymbolsPerCodewordMax(int value) {
        this.symbolsPerCodewordMax = value;
    }

    public boolean isSetSymbolsPerCodewordMax() {
        return (this.symbolsPerCodewordMax!= null);
    }

    public void unsetSymbolsPerCodewordMax() {
        this.symbolsPerCodewordMax = null;
    }

    /**
     * Gets the value of the shape property.
     * 
     * @return
     *     possible object is
     *     {@link DataMatrixShapeType }
     *     
     */
    public DataMatrixShapeType getShape() {
        if (shape == null) {
            return DataMatrixShapeType.DEFAULT;
        } else {
            return shape;
        }
    }

    /**
     * Sets the value of the shape property.
     * 
     * @param value
     *     allowed object is
     *     {@link DataMatrixShapeType }
     *     
     */
    public void setShape(DataMatrixShapeType value) {
        this.shape = value;
    }

    public boolean isSetShape() {
        return (this.shape!= null);
    }

}
